aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/loader/ncch.h
diff options
context:
space:
mode:
authorGravatar bunnei <ericbunnie@gmail.com>2014-06-18 23:53:22 -0400
committerGravatar bunnei <ericbunnie@gmail.com>2014-06-24 19:30:05 -0400
commit3da2bc6830e05d943c4d131a3167c2df25bff344 (patch)
tree8f77cc09046ea8be33eb9816ffbf89d9cecdf524 /src/core/loader/ncch.h
parent7889cafc76ac99b8509fa3cd1558a09f8a7e5f91 (diff)
NCCH: Fixes reduce unnecessary logging and load logo/banner/etc. sections correctly.
Loader: Added ErrorNotUsed ReturnStatus type to specify when something is not used.
Diffstat (limited to 'src/core/loader/ncch.h')
-rw-r--r--src/core/loader/ncch.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/core/loader/ncch.h b/src/core/loader/ncch.h
index 3aae5417..525a5aef 100644
--- a/src/core/loader/ncch.h
+++ b/src/core/loader/ncch.h
@@ -159,12 +159,13 @@ public:
private:
/**
* Reads an application section of an NCCH file into AppLoader (e.g. .code, .logo, etc.)
* @param file Handle to file to read from
* @param name Name of section to read out of NCCH file
* @param buffer Buffer to read section into.
+ * @return ResultStatus result of function
*/
- const ResultStatus LoadSection(File::IOFile& file, const char* name,
+ const ResultStatus LoadSectionExeFS(File::IOFile& file, const char* name,
std::vector<u8>& buffer);
/**
@@ -159,12 +159,13 @@ public:
private:
/**
- * Reads an application section of an NCCH file into AppLoader (e.g. .code, .logo, etc.)
+ * Reads an application ExeFS section of an NCCH file into AppLoader (e.g. .code, .logo, etc.)
* @param file Handle to file to read from
* @param name Name of section to read out of NCCH file